==> org.eclipse.incquery.uml.source_1.0.0.201504101636.jar: org/eclipse/incquery/uml/derivedfeatures/NamedElementClientDependencyMatch.java <==
package org.eclipse.incquery.uml.derivedfeatures;

import java.util.Arrays;
import java.util.List;
import org.eclipse.incquery.runtime.api.IPatternMatch;
import org.eclipse.incquery.runtime.api.impl.BasePatternMatch;
import org.eclipse.incquery.runtime.exception.IncQueryException;
import org.eclipse.incquery.uml.derivedfeatures.util.NamedElementClientDependencyQuerySpecification;
import org.eclipse.uml2.uml.Dependency;
import org.eclipse.uml2.uml.NamedElement;

/**
 * Pattern-specific match representation of the org.eclipse.incquery.uml.derivedfeatures.namedElementClientDependency pattern,
 * to be used in conjunction with {@link NamedElementClientDependencyMatcher}.
 * 
 * <p>Class fields correspond to parameters of the pattern. Fields with value null are considered unassigned.
 * Each instance is a (possibly partial) substitution of pattern parameters,
 * usable to represent a match of the pattern in the result of a query,
 * or to specify the bound (fixed) input parameters when issuing a query.
 * 
 * @see NamedElementClientDependencyMatcher
 * @see NamedElementClientDependencyProcessor
 * 
 */
@SuppressWarnings("all")
public abstract class NamedElementClientDependencyMatch extends BasePatternMatch {
  private NamedElement fSelf;
  
  private Dependency fD;
  
  private static List<String> parameterNames = makeImmutableList("self", "d");
  
  private NamedElementClientDependencyMatch(final NamedElement pSelf, final Dependency pD) {
    this.fSelf = pSelf;
    this.fD = pD;
  }
  
  @Override
  public Object get(final String parameterName) {
    if ("self".equals(parameterName)) return this.fSelf;
    if ("d".equals(parameterName)) return this.fD;
    return null;
  }
  
  public NamedElement getSelf() {
    return this.fSelf;
  }
  
  public Dependency getD() {
    return this.fD;
  }
  
  @Override
  public boolean set(final String parameterName, final Object newValue) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    if ("self".equals(parameterName) ) {
    	this.fSelf = (org.eclipse.uml2.uml.NamedElement) newValue;
    	return true;
    }
    if ("d".equals(parameterName) ) {
    	this.fD = (org.eclipse.uml2.uml.Dependency) newValue;
    	return true;
    }
    return false;
  }
  
  public void setSelf(final NamedElement pSelf) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fSelf = pSelf;
  }
  
  public void setD(final Dependency pD) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fD = pD;
  }
  
  @Override
  public String patternName() {
    return "org.eclipse.incquery.uml.derivedfeatures.namedElementClientDependency";
  }
  
  @Override
  public List<String> parameterNames() {
    return NamedElementClientDependencyMatch.parameterNames;
  }
  
  @Override
  public Object[] toArray() {
    return new Object[]{fSelf, fD};
  }
  
  @Override
  public NamedElementClientDependencyMatch toImmutable() {
    return isMutable() ? newMatch(fSelf, fD) : this;
  }
  
  @Override
  public String prettyPrint() {
    StringBuilder result = new StringBuilder();
    result.append("\"self\"=" + prettyPrintValue(fSelf) + ", ");
    
    result.append("\"d\"=" + prettyPrintValue(fD)
    );
    return result.toString();
  }
  
  @Override
  public int hashCode() {
    final int prime = 31;
    int result = 1;
    result = prime * result + ((fSelf == null) ? 0 : fSelf.hashCode());
    result = prime * result + ((fD == null) ? 0 : fD.hashCode());
    return result;
  }
  
  @Override
  public boolean equals(final Object obj) {
    if (this == obj)
    	return true;
    if (!(obj instanceof NamedElementClientDependencyMatch)) { // this should be infrequent
    	if (obj == null) {
    		return false;
    	}
    	if (!(obj instanceof IPatternMatch)) {
    		return false;
    	}
    	IPatternMatch otherSig  = (IPatternMatch) obj;
    	if (!specification().equals(otherSig.specification()))
    		return false;
    	return Arrays.deepEquals(toArray(), otherSig.toArray());
    }
    NamedElementClientDependencyMatch other = (NamedElementClientDependencyMatch) obj;
    if (fSelf == null) {if (other.fSelf != null) return false;}
    else if (!fSelf.equals(other.fSelf)) return false;
    if (fD == null) {if (other.fD != null) return false;}
    else if (!fD.equals(other.fD)) return false;
    return true;
  }
  
  @Override
  public NamedElementClientDependencyQuerySpecification specification() {
    try {
    	return NamedElementClientDependencyQuerySpecification.instance();
    } catch (IncQueryException ex) {
     	// This cannot happen, as the match object can only be instantiated if the query specification exists
     	throw new IllegalStateException (ex);
    }
  }
  
  /**
   * Returns an empty, mutable match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @return the empty match.
   * 
   */
  public static NamedElementClientDependencyMatch newEmptyMatch() {
    return new Mutable(null, null);
  }
  
  /**
   * Returns a mutable (partial) match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @param pSelf the fixed value of pattern parameter self, or null if not bound.
   * @param pD the fixed value of pattern parameter d, or null if not bound.
   * @return the new, mutable (partial) match object.
   * 
   */
  public static NamedElementClientDependencyMatch newMutableMatch(final NamedElement pSelf, final Dependency pD) {
    return new Mutable(pSelf, pD);
  }
  
  /**
   * Returns a new (partial) match.
   * This can be used e.g. to call the matcher with a partial match.
   * <p>The returned match will be immutable. Use {@link #newEmptyMatch()} to obtain a mutable match object.
   * @param pSelf the fixed value of pattern parameter self, or null if not bound.
   * @param pD the fixed value of pattern parameter d, or null if not bound.
   * @return the (partial) match object.
   * 
   */
  public static NamedElementClientDependencyMatch newMatch(final NamedElement pSelf, final Dependency pD) {
    return new Immutable(pSelf, pD);
  }
  
  private static final class Mutable extends NamedElementClientDependencyMatch {
    Mutable(final NamedElement pSelf, final Dependency pD) {
      super(pSelf, pD);
    }
    
    @Override
    public boolean isMutable() {
      return true;
    }
  }
  
  private static final class Immutable extends NamedElementClientDependencyMatch {
    Immutable(final NamedElement pSelf, final Dependency pD) {
      super(pSelf, pD);
    }
    
    @Override
    public boolean isMutable() {
      return false;
    }
  }
}

==> org.eclipse.incquery.uml.source_1.2.0.201602080945.jar: org/eclipse/incquery/uml/derivedfeatures/NamedElementClientDependencyMatch.java <==
package org.eclipse.incquery.uml.derivedfeatures;

import java.util.Arrays;
import java.util.List;
import org.eclipse.incquery.runtime.api.IPatternMatch;
import org.eclipse.incquery.runtime.api.impl.BasePatternMatch;
import org.eclipse.incquery.runtime.exception.IncQueryException;
import org.eclipse.incquery.uml.derivedfeatures.util.NamedElementClientDependencyQuerySpecification;
import org.eclipse.uml2.uml.Dependency;
import org.eclipse.uml2.uml.NamedElement;

/**
 * Pattern-specific match representation of the org.eclipse.incquery.uml.derivedfeatures.namedElementClientDependency pattern,
 * to be used in conjunction with {@link NamedElementClientDependencyMatcher}.
 * 
 * <p>Class fields correspond to parameters of the pattern. Fields with value null are considered unassigned.
 * Each instance is a (possibly partial) substitution of pattern parameters,
 * usable to represent a match of the pattern in the result of a query,
 * or to specify the bound (fixed) input parameters when issuing a query.
 * 
 * @see NamedElementClientDependencyMatcher
 * @see NamedElementClientDependencyProcessor
 * 
 */
@SuppressWarnings("all")
public abstract class NamedElementClientDependencyMatch extends BasePatternMatch {
  private NamedElement fSelf;
  
  private Dependency fD;
  
  private static List<String> parameterNames = makeImmutableList("self", "d");
  
  private NamedElementClientDependencyMatch(final NamedElement pSelf, final Dependency pD) {
    this.fSelf = pSelf;
    this.fD = pD;
  }
  
  @Override
  public Object get(final String parameterName) {
    if ("self".equals(parameterName)) return this.fSelf;
    if ("d".equals(parameterName)) return this.fD;
    return null;
  }
  
  public NamedElement getSelf() {
    return this.fSelf;
  }
  
  public Dependency getD() {
    return this.fD;
  }
  
  @Override
  public boolean set(final String parameterName, final Object newValue) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    if ("self".equals(parameterName) ) {
    	this.fSelf = (NamedElement) newValue;
    	return true;
    }
    if ("d".equals(parameterName) ) {
    	this.fD = (Dependency) newValue;
    	return true;
    }
    return false;
  }
  
  public void setSelf(final NamedElement pSelf) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fSelf = pSelf;
  }
  
  public void setD(final Dependency pD) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fD = pD;
  }
  
  @Override
  public String patternName() {
    return "org.eclipse.incquery.uml.derivedfeatures.namedElementClientDependency";
  }
  
  @Override
  public List<String> parameterNames() {
    return NamedElementClientDependencyMatch.parameterNames;
  }
  
  @Override
  public Object[] toArray() {
    return new Object[]{fSelf, fD};
  }
  
  @Override
  public NamedElementClientDependencyMatch toImmutable() {
    return isMutable() ? newMatch(fSelf, fD) : this;
  }
  
  @Override
  public String prettyPrint() {
    StringBuilder result = new StringBuilder();
    result.append("\"self\"=" + prettyPrintValue(fSelf) + ", ");
    
    result.append("\"d\"=" + prettyPrintValue(fD)
    );
    return result.toString();
  }
  
  @Override
  public int hashCode() {
    final int prime = 31;
    int result = 1;
    result = prime * result + ((fSelf == null) ? 0 : fSelf.hashCode());
    result = prime * result + ((fD == null) ? 0 : fD.hashCode());
    return result;
  }
  
  @Override
  public boolean equals(final Object obj) {
    if (this == obj)
    	return true;
    if (!(obj instanceof NamedElementClientDependencyMatch)) { // this should be infrequent
    	if (obj == null) {
    		return false;
    	}
    	if (!(obj instanceof IPatternMatch)) {
    		return false;
    	}
    	IPatternMatch otherSig  = (IPatternMatch) obj;
    	if (!specification().equals(otherSig.specification()))
    		return false;
    	return Arrays.deepEquals(toArray(), otherSig.toArray());
    }
    NamedElementClientDependencyMatch other = (NamedElementClientDependencyMatch) obj;
    if (fSelf == null) {if (other.fSelf != null) return false;}
    else if (!fSelf.equals(other.fSelf)) return false;
    if (fD == null) {if (other.fD != null) return false;}
    else if (!fD.equals(other.fD)) return false;
    return true;
  }
  
  @Override
  public NamedElementClientDependencyQuerySpecification specification() {
    try {
    	return NamedElementClientDependencyQuerySpecification.instance();
    } catch (IncQueryException ex) {
     	// This cannot happen, as the match object can only be instantiated if the query specification exists
     	throw new IllegalStateException (ex);
    }
  }
  
  /**
   * Returns an empty, mutable match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @return the empty match.
   * 
   */
  public static NamedElementClientDependencyMatch newEmptyMatch() {
    return new Mutable(null, null);
  }
  
  /**
   * Returns a mutable (partial) match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @param pSelf the fixed value of pattern parameter self, or null if not bound.
   * @param pD the fixed value of pattern parameter d, or null if not bound.
   * @return the new, mutable (partial) match object.
   * 
   */
  public static NamedElementClientDependencyMatch newMutableMatch(final NamedElement pSelf, final Dependency pD) {
    return new Mutable(pSelf, pD);
  }
  
  /**
   * Returns a new (partial) match.
   * This can be used e.g. to call the matcher with a partial match.
   * <p>The returned match will be immutable. Use {@link #newEmptyMatch()} to obtain a mutable match object.
   * @param pSelf the fixed value of pattern parameter self, or null if not bound.
   * @param pD the fixed value of pattern parameter d, or null if not bound.
   * @return the (partial) match object.
   * 
   */
  public static NamedElementClientDependencyMatch newMatch(final NamedElement pSelf, final Dependency pD) {
    return new Immutable(pSelf, pD);
  }
  
  private static final class Mutable extends NamedElementClientDependencyMatch {
    Mutable(final NamedElement pSelf, final Dependency pD) {
      super(pSelf, pD);
    }
    
    @Override
    public boolean isMutable() {
      return true;
    }
  }
  
  private static final class Immutable extends NamedElementClientDependencyMatch {
    Immutable(final NamedElement pSelf, final Dependency pD) {
      super(pSelf, pD);
    }
    
    @Override
    public boolean isMutable() {
      return false;
    }
  }
}
